]> git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - sv_user.c
sv_user: Rename SV_ClientThink to SV_PlayerPhysics to clarify its purpose
[xonotic/darkplaces.git] / sv_user.c
index 16abf771dd4374f45c4721226995aa920cf12186..be54fd3c3d8f3183d827b14313520e9f80501e1f 100644 (file)
--- a/sv_user.c
+++ b/sv_user.c
@@ -562,13 +562,13 @@ static void SV_AirMove (void)
 
 /*
 ===================
-SV_ClientThink
+SV_PlayerPhysics
 
 the move fields specify an intended velocity in pix/sec
 the angle fields specify an exact angular motion in degrees
 ===================
 */
-void SV_ClientThink (void)
+void SV_PlayerPhysics (void)
 {
        prvm_prog_t *prog = SVVM_prog;
        vec3_t v_angle, angles, velocity;
@@ -579,7 +579,7 @@ void SV_ClientThink (void)
        // make sure the velocity is sane (not a NaN)
        SV_CheckVelocity(host_client->edict);
 
// LadyHavoc: QuakeC replacement for SV_ClientThink (player movement)
        if (PRVM_serverfunction(SV_PlayerPhysics) && sv_playerphysicsqc.integer)
        {
                PRVM_serverglobalfloat(time) = sv.time;
@@ -579,7 +579,7 @@ void SV_ClientThink (void)
        SV_CheckVelocity(host_client->edict);
 
-       // LadyHavoc: QuakeC replacement for SV_ClientThink (player movement)
+       // LadyHavoc: QuakeC replacement for SV_PlayerPhysics (player movement)
        if (PRVM_serverfunction(SV_PlayerPhysics) && sv_playerphysicsqc.integer)
        {